@@ -1,3 +1,5 @@
+from typing import Dict, Tuple
+
 import torch
 
 from dataclasses import dataclass
@@ -71,6 +73,15 @@ class FlowDatasetPrecondition(ICondition):
         return self
 
 
+class TensorDict(dict):
+
+    def __len__(self):
+        for key, value in self.items():
+            if key != 'gt':
+                return len(value)
+        return super().__len__()
+
+
 class FlowDatasetDict(IOut):
 
     def __init__(self, prefix, data=None, available=None):
@@ -102,12 +113,21 @@ class FlowDatasetDict(IOut):
             y[key] = targets
         X['gt'] = self.gt
         X['gt']['_availability'] = self.available
-        return X, y
+        X['gt']['_targets'] = y
+        return TensorDict(X), y
 
 
 class FlowDataset(Dataset, IFlowTask):
 
     def __init__(self, task_flow, prefix=''):
+        """
+        Creates a dataset object for a given task flow.
+
+        :param task_flow: The task flow object.
+
+        :param prefix: The prefix path (will be appended before the task flow name)
+
+        """
         self._task_flow = task_flow
         # Save a reference to the flow function of the original class
         # We will then call it by replacing the self, this way effectively running
@@ -125,12 +145,14 @@ class FlowDataset(Dataset, IFlowTask):
                 setattr(self, key, instance)
         self.prefix = prefix
 
-    def __getitem__(self, item):
+    def __getitem__(self, item: int) -> Tuple[Dict, Dict]:
         """
         This method is going to execute the flow given in the constructor, passing around the index variable `item` in
-        the class `IndexHolder`
-        :param item:
-        :return:
+        the class :class:`IndexHolder`.
+
+        :param item: The index in the dataset.
+
+        :return: A tuple X, y of two dictionaries
         """
         flow_dataset_dict = self.flow(self, IndexHolder(item), FlowDatasetDict(self.prefix, {}))
         inputs = self._task_flow.get_inputs()
