@@ -1,12 +1,10 @@
 from dataclasses import dataclass
 
 import torch
-from torch import nn
 from transformers.modeling_bert import BertOnlyMLMHead
 
-from dnn_cool.decoders import ClassificationDecoder
 from dnn_cool.losses import LanguageModelCrossEntropyLoss, ReducedPerSample
-from dnn_cool.missing_values import positive_values
+from dnn_cool.missing_values import all_correct
 from dnn_cool.task_flow import Task
 
 
@@ -19,10 +17,10 @@ class MaskedLanguageModelingTask(Task):
             'labels': labels,
             'loss': LanguageModelCrossEntropyLoss(),
             'per_sample_loss': ReducedPerSample(LanguageModelCrossEntropyLoss(reduction='none'), reduction=torch.mean),
-            'available_func': positive_values,
+            'available_func': all_correct,
             'inputs': inputs,
-            'activation': nn.Softmax(dim=-1),
-            'decoder': ClassificationDecoder(),
+            'activation': None,
+            'decoder': None,
             'module': BertOnlyMLMHead(config),
             'metrics': ()
         }
